@@ -42,7 +42,7 @@ use overload
 # CVS ID: $Id$
 
 use vars qw/ $VERSION /;
-$VERSION = '0.06';
+$VERSION = '0.07';
 
 # hash of allowed lower-cased constructor keys with
 # corresponding accessor method
@@ -351,7 +351,13 @@ sub stringify {
 
     if ($min == $max) {
       # no range
-      return "==$min";
+      if ($self->inc_min() or $self->inc_max()) {
+        # A single value.
+        return "==$min";
+      } else {
+        # This interval matches nothing.
+        return "{}";
+      }
     } elsif ($max < $min) {
       return "<$inc_max_ub$max and >$inc_min_ub$min";
     } else {
@@ -466,8 +472,10 @@ Determine whether a supplied value is within the defined intervals.
 
 If both intervals are undefined, always returns true.
 
-If the min == max, returns true if the supplied value is that
-value, regardless of IncMin and IncMax setttings.
+B<Note:> If the min == max, returns true if the supplied value is that
+value, but only if either IncMin or IncMax is true.
+I<This is a change in version 0.06:> previously this method returned
+true in this case regardless of IncMin and IncMax setttings.
 
 If the interval is positive definite, always returns false if the
 supplied value is negative.
@@ -539,7 +547,7 @@ sub contains {
       if ($self->inc_max) {
 	$contains = 1 if $value <= $max;
       } else {
-	$contains = 1 if $value <= $max;
+	$contains = 1 if $value < $max;
       }
     } elsif (defined $min) {
       if ($self->inc_min) {
@@ -583,24 +591,28 @@ so the routine dies if such a situation arises.
 
 sub intersection {
   my $self = shift;
-  my $new = shift;
+  my $int2 = shift;
 
   # Check input
-  return 0 unless defined $new;
-  return 0 unless UNIVERSAL::isa($new,"Number::Interval");
+  return 0 unless defined $int2;
+  return 0 unless UNIVERSAL::isa($int2,"Number::Interval");
+
+  # Create an alternate reference to $self to use in case of swapping
+  # the variables around.
+  my $int1 = $self;
 
   # Get the values
-  my $max1 = $self->max;
-  my $min1 = $self->min;
-  my $max2 = $new->max;
-  my $min2 = $new->min;
+  my $max1 = $int1->max;
+  my $min1 = $int1->min;
+  my $max2 = $int2->max;
+  my $min2 = $int2->min;
 
-  my $inverted1 = $self->isinverted;
-  my $inverted2 = $new->isinverted;
+  my $inverted1 = $int1->isinverted;
+  my $inverted2 = $int2->isinverted;
   my $inverted = $inverted1 || $inverted2;
 
-  my $bound1 = $self->isbound;
-  my $bound2 = $new->isbound;
+  my $bound1 = $int1->isbound;
+  my $bound2 = $int2->isbound;
   my $bound  = $bound1 || $bound2;
 
   my $outmax;
@@ -628,7 +640,8 @@ sub intersection {
 	# swap if needed, to have everything as IX
 	my $nowbound;
 	if ($inverted2) {
-	  ($max1,$min1,$max2,$min2) = ($max2,$min2,$max1,$min1);
+	  ($max1,$min1,$max2,$min2,$int1,$int2) =
+            ($max2,$min2,$max1,$min1,$int2,$int1);
 	  # determine bound state of #1 before losing order information
 	  $nowbound = $bound1;
 	} else {
@@ -740,7 +753,8 @@ sub intersection {
 	#print "---------- BU/UB -----------\n";
 	# swap if needed, to have everything as BU
 	if ($bound2) {
-	  ($max1,$min1,$max2,$min2) = ($max2,$min2,$max1,$min1);
+	  ($max1,$min1,$max2,$min2,$int1,$int2) =
+            ($max2,$min2,$max1,$min1,$int2,$int1);
 	}
 
 	# unbound is now guaranteed to be (2)
@@ -832,9 +846,9 @@ sub intersection {
   if (defined $outmax or defined $outmin) {
     # Need to check the inc_min and inc_max settings
     my $inc_max = $self->_checkinc( $outmax, $max1, $max2,
-				    $self->inc_max, $new->inc_max );
+				    $int1->inc_max, $int2->inc_max );
     my $inc_min = $self->_checkinc( $outmin, $min1, $min2,
-				    $self->inc_min, $new->inc_min );
+				    $int1->inc_min, $int2->inc_min );
 
     # Abort if the min and max are the same and we
     # are not including the bounds in the interval
